@@ -69,7 +69,7 @@ class VisionClassifierTrainer:
     self.augmentation      = augmentation
     self.ids2labels        = self.model.config.id2label
     self.labels2ids        = self.model.config.label2id
-    
+
     print(self.ids2labels)
     print(self.labels2ids)
 
@@ -164,7 +164,7 @@ class VisionClassifierTrainer:
     all_target, all_preds = self.__evaluate()
 
     # Get the labels as a list
-    labels = list(self.ids2labels.values())
+    labels = list(self.labels2ids.values())
 
     # Compute f-score
     precision, recall, fscore, support = f_score(all_target, all_preds)
@@ -176,9 +176,9 @@ class VisionClassifierTrainer:
         table_f_score.append(
           [
               labels[i],
-              str(round(precision[i] * 100,2)) + " %",
-              str(round(recall[i] * 100,2)) + " %",
-              str(round(fscore[i] * 100,2)) + " %",
+              ("0" if precision[i] < 1 else str(round(precision[i] * 100,2))) + " %",
+              ("0" if recall[i]    < 1 else str(round(recall[i]    * 100,2))) + " %",
+              ("0" if fscore[i]    < 1 else str(round(fscore[i]    * 100,2))) + " %",
               support[i],
           ]
         )
